@@ -7,7 +7,7 @@ use Fcntl 'O_CREAT', 'O_RDWR', 'LOCK_EX', 'LOCK_SH', 'O_WRONLY', 'O_RDONLY';
 sub O_ACCMODE () { O_RDONLY | O_RDWR | O_WRONLY }
 
 
-$VERSION = "1.01";
+$VERSION = "1.04";
 my $DEFAULT_MEMORY_SIZE = 1<<21;    # 2 megabytes
 my $DEFAULT_AUTODEFER_THRESHHOLD = 3; # 3 records
 my $DEFAULT_AUTODEFER_FILELEN_THRESHHOLD = 65536; # 16 disk blocksful
@@ -170,6 +170,7 @@ sub _fetch {
     return unless defined $o;
   }
 
+  my $fh = $self->{FH};
   $self->_seek($n);             # we can do this now that offsets is populated
   my $rec = $self->_read_record;
 
@@ -438,7 +439,8 @@ sub _splice {
     if ($pos < 0) {
       $pos += $oldsize;
       if ($pos < 0) {
-        croak "Modification of non-creatable array value attempted, subscript $oldpos";
+        croak "Modification of non-creatable array value attempted, " .
+              "subscript $oldpos";
       }
     }
 
@@ -675,7 +677,7 @@ sub _upcopy {
   } elsif ($dpos == $spos) {
     return;
   }
-  
+
   while (! defined ($len) || $len > 0) {
     my $readsize = ! defined($len) ? $blocksize
                : $len > $blocksize ? $blocksize
@@ -884,7 +886,7 @@ sub _fill_offsets {
 
   my $fh = $self->{fh};
   local *OFF = $self->{offsets};
-  
+
   $self->_seek(-1);           # tricky -- see comment at _seek
 
   # Tels says that inlining read_record() would make this loop
@@ -1013,7 +1015,7 @@ sub flock {
   my $fh = $self->{fh};
   $op = LOCK_EX unless defined $op;
   my $locked = flock $fh, $op;
-  
+
   if ($locked && ($op & (LOCK_EX | LOCK_SH))) {
     # If you're locking the file, then presumably it's because
     # there might have been a write access by another process.
@@ -1048,7 +1050,7 @@ sub offset {
     # If it's still undefined, there is no such record, so return 'undef'
     return unless defined $o;
    }
- 
+
   $self->{offsets}[$n];
 }
 
@@ -1341,7 +1343,8 @@ sub _check_integrity {
       }
       if (! defined $offset && $self->{eof}) {
         $good = 0;
-        _ci_warn("The offset table was marked complete, but it is missing element $.");
+        _ci_warn("The offset table was marked complete, but it is missing " .
+                 "element $.");
       }
     }
     if (@{$self->{offsets}} > $.+1) {
@@ -1397,14 +1400,16 @@ sub _check_integrity {
 
   # Total size of deferbuffer should not exceed the specified limit
   if ($deferred_s > $self->{dw_size}) {
-    _ci_warn("buffer size is $self->{deferred_s} which exceeds the limit of $self->{dw_size}");
+    _ci_warn("buffer size is $self->{deferred_s} which exceeds the limit " .
+             "of $self->{dw_size}");
     $good = 0;
   }
 
   # Total size of cached data should not exceed the specified limit
   if ($deferred_s + $cached > $self->{memory}) {
     my $total = $deferred_s + $cached;
-    _ci_warn("total stored data size is $total which exceeds the limit of $self->{memory}");
+    _ci_warn("total stored data size is $total which exceeds the limit " .
+             "of $self->{memory}");
     $good = 0;
   }
 
@@ -2008,32 +2013,32 @@ Tie::File - Access the lines of a disk file via a Perl array
 
 =head1 SYNOPSIS
 
-	# This file documents Tie::File version 0.98
-	use Tie::File;
+ # This file documents Tie::File version 0.98
+ use Tie::File;
 
-	tie @array, 'Tie::File', filename or die ...;
+ tie @array, 'Tie::File', filename or die ...;
 
-	$array[13] = 'blah';     # line 14 of the file is now 'blah'
-	print $array[42];        # display line 43 of the file
+ $array[13] = 'blah';     # line 13 of the file is now 'blah'
+ print $array[42];        # display line 42 of the file
 
-	$n_recs = @array;        # how many records are in the file?
-	$#array -= 2;            # chop two records off the end
+ $n_recs = @array;        # how many records are in the file?
+ $#array -= 2;            # chop two records off the end
 
 
-	for (@array) {
-	  s/PERL/Perl/g;         # Replace PERL with Perl everywhere in the file
-	}
+ for (@array) {
+   s/PERL/Perl/g;        # Replace PERL with Perl everywhere in the file
+ }
 
-	# These are just like regular push, pop, unshift, shift, and splice
-	# Except that they modify the file in the way you would expect
+ # These are just like regular push, pop, unshift, shift, and splice
+ # Except that they modify the file in the way you would expect
 
-	push @array, new recs...;
-	my $r1 = pop @array;
-	unshift @array, new recs...;
-	my $r2 = shift @array;
-	@old_recs = splice @array, 3, 7, new recs...;
+ push @array, new recs...;
+ my $r1 = pop @array;
+ unshift @array, new recs...;
+ my $r2 = shift @array;
+ @old_recs = splice @array, 3, 7, new recs...;
 
-	untie @array;            # all finished
+ untie @array;            # all finished
 
 
 =head1 DESCRIPTION
@@ -2093,9 +2098,9 @@ the same thing:
 	$array[17] = "Cherry pie";
 	$array[17] = "Cherry pie\n";
 
-The result is that the contents of line 18 of the file will be
-replaced with "Cherry pie"; a newline character will separate line 18
-from line 19.  This means that this code will do nothing:
+The result is that the contents of line 17 of the file will be
+replaced with "Cherry pie"; a newline character will separate line 17
+from line 18.  This means that this code will do nothing:
 
 	chomp $array[17];
 
@@ -2169,8 +2174,8 @@ The default memory limit is 2Mib.  You can adjust the maximum read
 cache size by supplying the C<memory> option.  The argument is the
 desired cache size, in bytes.
 
-	# I have a lot of memory, so use a large cache to speed up access
-	tie @array, 'Tie::File', $file, memory => 20_000_000;
+ # I have a lot of memory, so use a large cache to speed up access
+ tie @array, 'Tie::File', $file, memory => 20_000_000;
 
 Setting the memory limit to 0 will inhibit caching; records will be
 fetched from disk every time you examine them.
@@ -2324,7 +2329,7 @@ the @array.
 
 Normally, modifying a C<Tie::File> array writes to the underlying file
 immediately.  Every assignment like C<$a[3] = ...> rewrites as much of
-the file as is necessary; typically, everything from line 4 through
+the file as is necessary; typically, everything from line 3 through
 the end will need to be rewritten.  This is the simplest and most
 transparent behavior.  Performance even for large files is reasonably
 good.
@@ -2360,7 +2365,7 @@ will be rewritten in a single pass.
 (Actually, the preceding discussion is something of a fib.  You don't
 need to enable deferred writing to get good performance for this
 common case, because C<Tie::File> will do it for you automatically
-unless you specifically tell it not to.  See L<"Autodeferring">,
+unless you specifically tell it not to.  See L</Autodeferring>,
 below.)
 
 Calling C<-E<gt>flush> returns the array to immediate-write mode.  If
@@ -2489,7 +2494,8 @@ C<rollback>, but it isn't, so don't.
 =item *
 
 There is a large memory overhead for each record offset and for each
-cache entry: about 310 bytes per cached data record, and about 21 bytes per offset table entry.
+cache entry: about 310 bytes per cached data record, and about 21 bytes
+per offset table entry.
 
 The per-record overhead will limit the maximum number of records you
 can access per file. Note that I<accessing> the length of the array
@@ -2511,7 +2517,7 @@ People sometimes point out that L<DB_File> will do something similar,
 and ask why C<Tie::File> module is necessary.
 
 There are a number of reasons that you might prefer C<Tie::File>.
-A list is available at C<http://perl.plover.com/TieFile/why-not-DB_File>.
+A list is available at C<L<http://perl.plover.com/TieFile/why-not-DB_File>>.
 
 =head1 AUTHOR
 
